@@ -5,9 +5,10 @@ Provide tool functions for working with Job Submission data
 from pathlib import Path
 from typing import Optional, cast
 
+from jobbergate_cli.config import settings
+from jobbergate_cli.exceptions import Abort
 from jobbergate_cli.requests import make_request
 from jobbergate_cli.schemas import JobbergateContext, JobSubmissionCreateRequestData, JobSubmissionResponse
-from jobbergate_cli.subapps.clusters.tools import validate_client_id
 
 
 def create_job_submission(
@@ -15,7 +16,7 @@ def create_job_submission(
     job_script_id: int,
     name: str,
     description: Optional[str] = None,
-    client_id: Optional[str] = None,
+    cluster_name: Optional[str] = None,
     execution_directory: Optional[Path] = None,
 ) -> JobSubmissionResponse:
     """
@@ -26,12 +27,9 @@ def create_job_submission(
     :param: job_script_id:       The ``id`` of the Job Script to submit to Slurm
     :param: name:                The name to attach to the Job Submission
     :param: description:         An optional description that may be added to the Job Submission
-    :param: client_id:           An optional client_id for the cluster where the job should be executed,
-                                 If left off, it will default to the client_id where this CLI is deployed.
-                                 This field is called (in the code) ``client_id`` even though it is presented to the
-                                 user as a name field. Armada uses textual, human-readable, parameterized names for the
-                                 cluster clients.
-                                 This value must appear in the available cluster names provided by the cluster-api.
+    :param: cluster_name:        An optional cluster_name for the cluster where the job should be executed,
+                                 If left off, it will default to the DEFAULT_CLUSTER_NAME from the settings.
+                                 If no default is set, an exception will be raised.
     :param: execution_directory: An optional directory where the job should be executed. If provided as a relative path,
                                  it will be constructed as an absolute path relative to the current working directory.
     :returns: The Job Submission data returned by the API after creating the new Job Submission
@@ -41,15 +39,23 @@ def create_job_submission(
     assert jg_ctx.client is not None, "jg_ctx.client is uninitialized"
     assert jg_ctx.persona is not None, "jg_ctx.persona is uninitialized"
 
-    if client_id is None:
-        client_id = jg_ctx.persona.identity_data.client_id
-    validate_client_id(jg_ctx, client_id)
+    if cluster_name is None:
+        cluster_name = settings.DEFAULT_CLUSTER_NAME
+
+    Abort.require_condition(
+        cluster_name is not None,
+        "No cluster name supplied and no default exists. Cannot submit to an unknown cluster!",
+        raise_kwargs=dict(
+            subject="No cluster Name",
+            support=True,
+        ),
+    )
 
     job_submission_data = JobSubmissionCreateRequestData(
         job_submission_name=name,
         job_submission_description=description,
         job_script_id=job_script_id,
-        client_id=client_id,
+        cluster_name=cluster_name,
     )
 
     if execution_directory is not None:
